==> nifi-2.0.0-source-release.zip: nifi-2.0.0/minifi/minifi-commons/minifi-commons-utils/src/main/java/org/apache/nifi/minifi/commons/utils/RetryUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nifi.minifi.commons.utils;

import java.util.Optional;
import java.util.function.Predicate;
import java.util.function.Supplier;

public final class RetryUtil {

    private RetryUtil() {
        throw new UnsupportedOperationException();
    }

    public static  <T> Optional<T> retry(Supplier<T> input, Predicate<T> predicate, int maxRetries, int pauseDurationMillis) {
        int retries = 0;
        while (true) {
            T t = input.get();
            if (predicate.test(t)) {
                return Optional.empty();
            }
            if (retries == maxRetries) {
                return Optional.ofNullable(t);
            }
            retries++;
            try {
                Thread.sleep(pauseDurationMillis);
            } catch (InterruptedException e) {
            }
        }
    }
}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/minifi/minifi-commons/minifi-commons-utils/src/main/java/org/apache/nifi/minifi/commons/utils/RetryUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nifi.minifi.commons.utils;

import java.util.Optional;
import java.util.function.Predicate;
import java.util.function.Supplier;

public final class RetryUtil {

    private RetryUtil() {
        throw new UnsupportedOperationException();
    }

    public static  <T> Optional<T> retry(Supplier<T> input, Predicate<T> predicate, int maxRetries, int pauseDurationMillis) {
        int retries = 0;
        while (true) {
            T t = input.get();
            if (predicate.test(t)) {
                return Optional.empty();
            }
            if (retries == maxRetries) {
                return Optional.ofNullable(t);
            }
            retries++;
            try {
                Thread.sleep(pauseDurationMillis);
            } catch (InterruptedException ignored) {
            }
        }
    }
}
